Module wire

Module wire 

Low level “wire” data types for encoding & decoding.

Structs

WireDecoder
WireEncoder
WireI32
Protobuf I32 wire type (fixed 32 bit values) used to encode the Protobuf types fixed32, sfixed32 and float.
WireI64
Protobuf I64 wire type (fixed 64 bit values) used to encode the Protobuf types fixed64, sfixed64 and double.
WireLenCalc
Helper to calculate the number of bytes used when encoding a given set of values.a
WireLenRef
LEN wire type that can be interpred as string, bytes, “embedded messages” and “packed repeated fields” Prototype types.
WireVarInt
Variable sized integer Protobuf wire value used to encode the Protobuf types int32, int64, uint32, uint64, sint32, sint64, bool and enum.

Enums

WireType
WireValueIntoError
Error when it is not possible to convert a WireValueRef to a specific Protobuf type.
WireValueRef
A “on the wire” protobuf value reference that can be furhter interpreted into a “proto type” based on it’s definition.