pub enum WireValueIntoError {
UnexpectedType {
expected: WireType,
actual: WireType,
},
VarIntValueTooBigFor32Bit(u64),
}Expand description
Error when it is not possible to convert a WireValueRef
to a specific Protobuf type.
Variants
UnexpectedType
Error if a WireValueRef is not WireValueRef::VarInt even though
it was expected to be one.
VarIntValueTooBigFor32Bit(u64)
Error if the value is too big for a 32 bit value.