pub struct WireDecoder<'a> {
pub data: &'a [u8],
}Fields
data: &'a [u8]Implementations
Sourceimpl<'a> WireDecoder<'a>
impl<'a> WireDecoder<'a>
pub fn new(data: &'a [u8]) -> WireDecoder<'a>
Sourcepub fn read_var_uint32(&mut self) -> Result<u32, DecodeError>
pub fn read_var_uint32(&mut self) -> Result<u32, DecodeError>
Read a VARINT uint32 from the data slice and move data
by the amount of read bytes.
Sourcepub fn read_var_uint64(&mut self) -> Result<u64, DecodeError>
pub fn read_var_uint64(&mut self) -> Result<u64, DecodeError>
Read a VARINT uint64 from the data slice and move data
by the amount of read bytes.
Sourcepub fn read_fixed32(&mut self) -> Result<u32, DecodeError>
pub fn read_fixed32(&mut self) -> Result<u32, DecodeError>
Read fixed sized u32 from the data slice and move data
by the amount of read bytes.
Sourcepub fn read_fixed64(&mut self) -> Result<u64, DecodeError>
pub fn read_fixed64(&mut self) -> Result<u64, DecodeError>
Read fixed sized u64 from the data slice and move data
by the amount of read bytes.
Sourcepub fn read_float(&mut self) -> Result<f32, DecodeError>
pub fn read_float(&mut self) -> Result<f32, DecodeError>
Read double from the data slice and move data
by the amount of read bytes.
Sourcepub fn read_double(&mut self) -> Result<f64, DecodeError>
pub fn read_double(&mut self) -> Result<f64, DecodeError>
Read double from the data slice and move data
by the amount of read bytes.
pub fn take_byte(&mut self) -> Result<u8, DecodeError>
pub fn take_4bytes(&mut self) -> Result<[u8; 4], DecodeError>
pub fn take_8bytes(&mut self) -> Result<[u8; 8], DecodeError>
pub fn take_nbyte(&mut self, n: usize) -> Result<&'a [u8], DecodeError>