Low level “wire” data types for encoding & decoding.
Structs
- Wire
Decoder - Wire
Encoder - WireI32
- Protobuf I32 wire type (fixed 32 bit values) used to
encode the Protobuf types
fixed32,sfixed32andfloat. - WireI64
- Protobuf I64 wire type (fixed 64 bit values) used to
encode the Protobuf types
fixed64,sfixed64anddouble. - Wire
LenCalc - Helper to calculate the number of bytes used when encoding a given set of values.a
- Wire
LenRef - LEN wire type that can be interpred as
string,bytes, “embedded messages” and “packed repeated fields” Prototype types. - Wire
VarInt - Variable sized integer Protobuf wire value used to
encode the Protobuf types
int32,int64,uint32,uint64,sint32,sint64,boolandenum.
Enums
- Wire
Type - Wire
Value Into Error - Error when it is not possible to convert a
WireValueRefto a specific Protobuf type. - Wire
Value Ref - A “on the wire” protobuf value reference that can be furhter interpreted into a “proto type” based on it’s definition.